@@ -37,7 +37,7 @@ def error_hooks(msg: str) -> None:
     for hook in ERROR_HOOKS:
         hook.process_msg(msg)
 
-temp = []
+
 def register_hook(level: int, hookClassStr: str) -> None:
     modulePath, hookName = re.search("(.*)\.(.*)", hookClassStr).groups()
     hook = getattr(import_module(modulePath), hookName)()
@@ -45,22 +45,11 @@ def register_hook(level: int, hookClassStr: str) -> None:
         raise Exception("hook must implements from logor.interface.IHook")
     if level >= ERROR:
         ERROR_HOOKS.append(hook)
-        return
     elif level > WARNING:
         WARNING_HOOKS.append(hook)
-        ERROR_HOOKS.append(hook)
-        return
     elif level > INFO:
         INFO_HOOKS.append(hook)
-        WARNING_HOOKS.append(hook)
-        ERROR_HOOKS.append(hook)
-        return
     elif level > DEBUG:
         DEBUG_HOOKS.append(hook)
-        INFO_HOOKS.append(hook)
-        WARNING_HOOKS.append(hook)
-        ERROR_HOOKS.append(hook)
-        return
     else:
         BASIC_HOOKS.append(hook)
-        return
